import tkinter as tk
import pandas as pd
import matplotlib.pyplot as plt
import pandastable as pt
from PIL import Image, ImageTk
from datetime import datetime

class EVChargingGUI:
    def __init__(self, window, title, size):
        self.window = window
        self.window.title(title)
        self.window.geometry(f'{size[0]}x{size[1]}')

        self.create_widgets()

        self.graph_bool = False

    def create_widgets(self):
        self.table_frame = tk.Frame(self.window)
        self.table_frame.pack(fill=tk.BOTH, expand=False)

        self.graph_frame = tk.Frame(self.window)
        self.graph_frame.pack(fill=tk.BOTH, expand=True)

        self.button1 = tk.Button(self.graph_frame, text='EV Charging Stations in the US')
        self.button1.grid(row=0, column=0)
        self.button2 = tk.Button(self.graph_frame, text='Ev Charging Stations Opened Time Series')
        self.button2.grid(row=0, column=1)

class EVChargingData:
    def __init__(self, data):
        self.data = data
        self.ev_data = self.data[(self.data['Fuel Type Code'] == 'ELEC') & 
                                (self.data['Open Date'].notnull())]

class EVChargingInfrastructure:
    def __init__(self, gui, data):
        self.gui = gui
        self.data = data

        self.table = pt.Table(self.gui.table_frame, dataframe=self.data)
        self.table.show()

        self.gui.button1.config(command=self.create_graph1)
        self.gui.button2.config(command=self.create_graph2)


        self.update_graph()

    
    def create_graph1(self):
        self.gui.graph_bool = True
        print(self.gui.graph_bool)

        data1 = self.data['State'].tolist()
        counts = {x: data1.count(x) for x in data1}

        # Extract the unique elements and their counts
        labels = list(counts.keys())
        values = list(counts.values())

        # Create a bar plot
        plt.figure(figsize=(20, 10))
        plt.bar(labels, values, width=3,  color='blue')
        plt.xlabel('State')
        plt.ylabel('Count')
        plt.title('EV Charging Stations in the US')

        plt.savefig('my_plot.png', dpi=60)


        self.update_graph()

    def create_graph2(self):
        self.gui.graph_bool = False
        print(self.gui.graph_bool)
        # TODO: create graph Ev Charging Stations Opened Time Series'

        dates = self.data['Open Date'].tolist()
        dates = [datetime.strptime(date, '%Y-%m-%d') for date in dates]

        # Sort the dates in ascending order
        dates.sort()

        # Generate the y-values representing the opening growth
        y_values = range(1, len(dates) + 1)

        # Create a line plot
        plt.plot(dates, y_values, marker='o')
        plt.xlabel('Open Date(1970 - 2015))')
        plt.ylabel('Opening Growth')
        plt.title('Ev Charging Stations Opened Time Series')

        plt.savefig('my_plot.png', dpi=60)


        self.update_graph()

    def display_graph1(self):
        print('graph 1')
        image = Image.open("my_plot.png")
        photo = ImageTk.PhotoImage(image, width=100, height=100)

        # Create a label with the image
        label = tk.Label(self.gui.graph_frame, image=photo)
        label.image = photo  # keep a reference to the image to prevent garbage collection

        # Pack the label onto the frame
        label.grid(row=1, column=0, columnspan=2)

    def display_graph2(self):
        print('graph 2')
        image = Image.open("my_plot.png")
        photo = ImageTk.PhotoImage(image)

        # Create a label with the image
        label = tk.Label(self.gui.graph_frame, image=photo)
        label.image = photo  # keep a reference to the image to prevent garbage collection

        # Pack the label onto the frame
        label.grid(row=1, column=0, columnspan=2)

    def update_graph(self):
        if self.gui.graph_bool:
            self.display_graph1()
        else:
            self.display_graph2()
        self.gui.window.after(1000, self.update_graph)

class EVChargingApp:
    def __init__(self, window, title, size, data):
        self.gui = EVChargingGUI(window, title, size)
        self.data = EVChargingData(data)
        self.infrastructure = EVChargingInfrastructure(self.gui, self.data.ev_data)
        
    def run(self):
        self.gui.window.mainloop()
