# EV ChargingStation Analysis App

## Description
The EV ChargingStation Analysis App that provides visualizations and analysis of electric vehicle charging stations in the US. It allows users to explore data related to the charging stations, such as the distribution of stations across states and the growth of stations over time.

![EV Charging App Screenshot](ev_charging_app_screenshot.png)

## Data Sources
The application uses the following data sources:

- Alternative Fuel Stations dataset: This dataset contains information about alternative fuel stations in the US, including electric vehicle charging stations. [Link to Dataset](https://catalog.data.gov/dataset/alternative-fueling-station-locations-422f2/resource/494cb60a-f2e6-4e62-a49d-79bdc083d3c1)

## Running the Application
Dependencies:
- Python 3
- Pandas
- Matplotlib
- PandasTable

To run the application, follow these steps:
1. Install the required dependencies using the package manager of your choice (pip install -r requirements.txt).
2. Download the Alternative Fuel Stations dataset from the provided link and save it as "alternative_fuel_stations.csv".
3. Run the "ev_charging_app.py" script using Python: `python ev_charging_app.py`.

## Design
### UML Class Diagram
![UML Class Diagram](uml_class_diagram.png)

### Sequence Diagram
![Sequence Diagram](sequence_diagram.png)

## Design Patterns Used
The EV Charging App uses the Model-View-Controller (MVC) design pattern to separate the application into three main components: the Model, the View, and the Controller. This separation allows for better organization and modularity of the code. The Model represents the data and provides the necessary operations, the View handles the user interface and visualization, and the Controller handles the communication between the Model and the View.

## Graph Algorithm Used
The EV Charging App models the problem of visualizing the growth of charging stations over time as a graph problem. The x-axis represents time, and the y-axis represents the number of charging stations. The algorithm used to solve this problem is a simple line plot, where each data point represents a specific date and the corresponding number of charging stations.

## Other Information
- The application utilizes the Pandas library for data manipulation and analysis, Matplotlib for data visualization, and PandasTable for displaying the data in a tabular format.
- The application demonstrates the usage of image handling using the PIL (Python Imaging Library) and Tkinter libraries to display the generated plots.
- Throughout the development of the application, important concepts such as data preprocessing, plotting, and GUI integration were learned and implemented.
